# HYMOG Data River Rhine V0.2 25.10.2017
#
# MetaData Analysis for raw Measurement Data
#
#-----------------------------------------------

#
# extract year
#
extract_year <- function(timeseries,year)
{
  # extract year
  ts=window(timeseries,start=as.POSIXct(sprintf("%4d-01-01 00:00:00",year),"UTC"),
            end  =as.POSIXct(sprintf("%4d-12-31 23:59:59",year),"UTC")) 
  return(ts)
}
#
# print MetaData of a time series 
#
printMetaData <- function(water_ts)
{
 print(paste(water_ts@name,": values",length(water_ts@timeseries),"NaN:",sum(is.na(water_ts@timeseries)),
             sprintf("%.1f%%",(sum(is.na(water_ts@timeseries)/length(water_ts@timeseries)*100)))))
 print(sprintf("                      min  %6.2f %s",min(water_ts@timeseries,na.rm=TRUE),water_ts@unit))
 print(sprintf("                      max  %6.2f",max(water_ts@timeseries,na.rm=TRUE),water_ts@unit))
 print(sprintf("                      mean %6.2f",mean(water_ts@timeseries,na.rm=TRUE),water_ts@unit))
 print(sprintf("                      sd   %6.2f",sd(water_ts@timeseries,na.rm=TRUE))) 
#
# annual values
#
 title_text="                      year "
 na_text   ="                      NA   "
 na2_text  ="                      NA % "
 min_text  ="                      min  "
 max_text  ="                      max  "
 mean_text ="                      mean "
 sd_text   ="                      sd   "
#
# loop on all years
#
 for(i in 1:19) 
  {
   year_time_series = extract_year(water_ts@timeseries,1988+i)
   title_text = paste(title_text,sprintf("    %4d",(1988+i)))
   na_text   = paste(na_text,sprintf("  %6d",sum(is.na(year_time_series))))
   na2_text  = paste(na2_text,sprintf("%8.2f",(100.-sum(!is.na(year_time_series))*100/(365*24))))
   min_text  = paste(min_text,sprintf("%8.2f",min(year_time_series,na.rm=TRUE)))
   max_text  = paste(max_text,sprintf("%8.2f",max(year_time_series,na.rm=TRUE)))
   mean_text = paste(mean_text,sprintf("%8.2f",mean(year_time_series,na.rm=TRUE)))
   sd_text   = paste(sd_text,sprintf("%8.2f",sd(year_time_series,na.rm=TRUE)))
  }
# print the results line by line 
 print(title_text)
 print(na_text)
 print(na2_text)
 print(min_text)
 print(max_text)
 print(mean_text)
 print(sd_text)
}

#
# write the output to a file
#
sink("MetaData.txt")
#
# print meta data of the time series 
#
printMetaData(h_RO)
printMetaData(q_RO)
printMetaData(h_WL)
printMetaData(q_WL)

sink() # close file 
